===============================
Kibitzr
===============================

.. image:: https://badges.gitter.im/kibitzr/Lobby.svg
   :alt: Join the chat at https://gitter.im/kibitzr/Lobby
   :target: https://gitter.im/kibitzr/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


.. image:: https://img.shields.io/pypi/v/kibitzr.svg
        :target: https://pypi.python.org/pypi/kibitzr

.. image:: https://img.shields.io/travis/kibitzr/kibitzr.svg
        :target: https://travis-ci.org/kibitzr/kibitzr

.. image:: https://readthedocs.org/projects/kibitzr/badge/?version=latest
        :target: https://kibitzr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://gitpitch.com/assets/badge.svg
        :target: https://gitpitch.com/kibitzr/kibitzr/master?grs=github&t=white
        :alt: GitPitch

Kibitzr is like a secret twin brother who does routine tasks and asks for nothing in return.

* Install with ``pip install kibitzr`` (Works with both Python 2 and 3)
* Configure recurrent tasks in ``kibitzr.yml``
* Put credentials in ``kibitzr-creds.yml``
* Launch with ``kibitzr``
* Problems? Ask in issues_, or gitter_

* Documentation: https://kibitzr.readthedocs.io.

Run with docker::

    $ docker run -v $PWD:/root/.config/kibitzr peterdemin/kibitzr


* Free software: MIT license

.. _Selenium: https://selenium-python.readthedocs.io/getting-started.html
.. _gitter: https://gitter.im/kibitzr/Lobby
.. _requests: http://docs.python-requests.org/en/master/
.. _issue: https://github.com/kibitzr/kibitzr/issues/new
.. _issues: https://github.com/kibitzr/kibitzr/issues/
.. _Python: https://www.python.org/
.. _bash: https://www.gnu.org/software/bash/
.. _Fork: https://github.com/kibitzr/kibitzr/
